## Remote Extensions

These are extension defintions we use, but we did not create.

* attack-flow.json
	* description: used for new `attack-flow`, `attack-action`, `attack-condition`, `attack-operator`, `attack-asset` SDO objects
	* source: https://github.com/center-for-threat-informed-defense/attack-flow/blob/main/stix/attack-flow-extension-2.0.0.json
* tlp-v2.json
	* description: used to extend properties of marking definition objects to define TLP v2 marking `TLP:CLEAR`, `TLP:GREEN`, `TLP:AMBER`, `TLP:AMBER+STRICT`, `TLP:RED`
	* https://github.com/oasis-open/cti-stix-common-objects/blob/main/objects/extension-definition/extension-definition--60a3c5c5-0d10-413e-aab3-9e08dde9e88d.json